.widget_bp_core_members_widget ul#members-list {
	margin: 15px 0 0 0;
	padding: 0;
	list-style: none;
}
	
	.widget_bp_core_members_widget ul#members-list li {
		min-height: 60px;
	}
	
	.widget_bp_core_members_widget ul#members-list li img.avatar {
		float: left;
		margin: 0 10px 0 0;
	}
	
	.widget_bp_core_members_widget ul#members-list li span.activity {
		font-size: 11px;
	}
	
.widget_bp_core_members_widget img#ajax-loader-members {
	float: right;
}