/* Blog Switcher */

#all-my-blogs-tab a.current {
	position: relative;
	padding-bottom: 10px;
}

#all-my-blogs {
	position: absolute;
	top: 30px;
	left: 0;
	right: 0;
	_width: 100%; /* IE6 Hack */
	margin: 4px 7px;
	padding: 6px 10px;
	font-size: 12px;
}

#all-my-blogs * {
	margin: 0;
}

form#all-my-blogs p, form#all-my-blogs p * {
	vertical-align: middle;
}

#all-my-blogs a {
	font-size: 10px;
	text-decoration: underline;
	margin: 0 14px;
}

#all-my-blogs a:hover, #all-my-blogs a:active  {
	text-decoration: none;
}

form#wpmu-search {
	position:absolute;
	right:0;
	top:0;
}

/* Site Admin Menu */
#adminmenu #menu-site div.wp-menu-image {
	background: transparent url("../images/site-admin.png") no-repeat scroll 0px -33px;
}

#adminmenu #menu-site:hover div.wp-menu-image {
	background: transparent url("../images/site-admin.png") no-repeat scroll 0px -1px;
}

/* Dashboard: MU Specific Data */
#dashboard_right_now p.musub {
	margin-top: 12px;
	border-top: 1px solid #ececec;
}

#dashboard_right_now td.b a.musublink {
	font-size: 16px;
}
